/*
 * hostinfo.c - Show the hostent structure for a hostname
 */
#include <sys/socket.h>
#include <netinet/in.h>
#include <arpa/inet.h>
#include <netdb.h>
#include <stdlib.h>
#include <stdio.h>
#include "helper.h"

int main(int argc, char *argv[])
{
     struct hostent *buf;
     struct in_addr **paddr;
     char **palias;

     /* Expect the IP addresss on the command-line */
     if(argc != 2) {
	  puts("USAGE: hostinfo <host name>");
	  exit(EXIT_FAILURE);
     }
     
     /* Do the lookup */
     if((buf = gethostbyname(argv[1])) == NULL)
	  herr_quit("gethostbyname");
     /* Got a valid hostname, so ... */
     printf("host info for %s\n", argv[1]);

     /* The canonical hostname */
     printf("name: %s\n", buf->h_name);

     /* All of the aliases */
     puts("aliases:");
     palias = buf->h_aliases;
     while(*palias) {
	  printf("\t%s\n", *palias);
	  palias++;
     }

     /* h_addrtype better be AF_INET */
     if(buf->h_addrtype == AF_INET)
	  puts("type: AF_INET");
     else
	  puts("type: unknown");
     printf("length: %d\n", buf->h_length);

     /* All of the IP addresses */
     puts("addresses:");
     paddr = (struct in_addr **)buf->h_addr_list;
     while(*paddr) {
	  printf("\t%s\n", inet_ntoa(**paddr));
	  paddr++;
     }

     exit(EXIT_SUCCESS);
}
