/*
 * mksock.c - Make and bind to a socket
 */
#include <sys/socket.h>
#include <sys/un.h>
#include <stdlib.h>
#include <stdio.h>
#include "helper.h"

int main(int argc, char *argv[])
{
     int sockfd;		/* File descriptor for socket */
     struct sockaddr_un srv;	/* Server's socket structure */
     socklen_t socklen;
     
     /* Expect the socket name on the command-line */
     if(argc != 2) {
	  puts("USAGE: mksock <filename>");
	  exit(EXIT_FAILURE);
     }

     /* Create the socket */
     if((sockfd = socket(PF_UNIX, SOCK_STREAM, 0)) < 0)
	  err_quit("socket");

     /* Initialize and set up the server structure */
     memset(&srv, 0, sizeof(srv));
     srv.sun_family = AF_UNIX;
     strncpy(srv.sun_path, argv[1], sizeof(srv.sun_path));

     /* Bind the socket to an address */
     if((bind(sockfd, (struct sockaddr *)&srv, SUN_LEN(&srv))) < 0)
	  err_quit("bind");

     /* Wait for incoming connections */
     if((listen(sockfd, 5)) < 0)
	  err_quit("listen");
     printf("socket available: %s\n", srv.sun_path);
     
     /* Loop forever, accepting all connections */
     while(accept(sockfd, (struct sockaddr *)&srv, &socklen) >= 0)
	  puts("new connection granted");

     exit(EXIT_SUCCESS);
}

