/*
 * netconn.c - Connect to a TCP/IP socket
 */
#include <sys/socket.h>
#include <netinet/in.h>
#include <arpa/inet.h>
#include <stdlib.h>
#include <stdio.h>
#include "helper.h"

int main(int argc, char *argv[])
{
     int sockfd;		/* File descriptor for socket */
     struct sockaddr_in cli;	/* Client's socket structure */
     socklen_t socklen;		/* Size of sockaddr */
     
     /* Expect the IP address on the command-line */
     if(argc != 2) {
	  puts("USAGE: netconn <ip address>");
	  exit(EXIT_FAILURE);
     }

     /* Create a socket */
     if((sockfd = socket(PF_INET, SOCK_STREAM, 0)) < 0)
	  err_quit("socket");

     /* Set up the client */
     memset(&cli, 0, sizeof(cli));
     cli.sin_family = AF_INET;
     cli.sin_port = htons(50000); /* Don't forget network byte order */
     /* This will self-destruct if the IP address is invalid */
     if(!(inet_aton(argv[1], &cli.sin_addr)))
	  herr_quit("inet_aton");

     /* Connect to the socket */
     socklen = sizeof(cli);
     if(connect(sockfd, (struct sockaddr *)&cli, socklen))
	  err_quit("connect");
     puts("connected to socket");

     exit(EXIT_SUCCESS);
}
     
